PackageMega
=========

|CircleCI master| |PyPI latest version| |PyPI Python version| |PyPI downloads| |GitHub license|

Simple package manager to download and keep track of biological databases.

Goals
-----

PackageMega is used to distribute `ModuleUltra <https://github.com/dcdanko/ModuleUltra>`_ pipelines.

See `recipes <./recipes/>`_ for examples.

Installation
------------

Be aware that PackageMega is still an Alpha. There are still bugs and some unimplemented features.

PackageMega is currently being used on Ubuntu and RHEL systems. It should work on any *nix system.

To install:


.. code-block:: bash

    pip install packagemega


Licence
-------
MIT License

Authors
-------

`ModuleUltra` was written by `David C. Danko <dcdanko@gmail.com>`_.


.. |CircleCI master| image:: https://img.shields.io/circleci/project/github/dcdanko/PackageMega/master.svg
    :alt: CircleCI master

.. |PyPI latest version| image:: https://img.shields.io/pypi/v/PackageMega.svg
    :target: https://pypi.python.org/pypi/PackageMega
    :alt: Latest PyPI version

.. |PyPI Python version| image:: https://img.shields.io/pypi/pyversions/PackageMega.svg
    :alt: PyPI - Python version

.. |PyPI downloads| image:: https://img.shields.io/pypi/dm/PackageMega.svg
    :alt: PyPI - Downloads

.. |GitHub license| image:: https://img.shields.io/github/license/dcdanko/PackageMega.svg
    :alt: GitHub license
